# Metrics

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**succeeded** | **int** | Number of successfully built commits |
**failed** | **int** | Number of commits that failed to build |
**total** | **int** | Total number of commits processed |


[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


